@@ -19,7 +19,6 @@ from datetime import datetime
 from isogeo_pysdk.checker import IsogeoChecker
 from isogeo_pysdk.decorators import ApiDecorators
 from isogeo_pysdk.models import Event, Metadata
-from isogeo_pysdk.utils import IsogeoUtils
 
 # #############################################################################
 # ########## Global #############
@@ -27,7 +26,6 @@ from isogeo_pysdk.utils import IsogeoUtils
 
 logger = logging.getLogger(__name__)
 checker = IsogeoChecker()
-utils = IsogeoUtils()
 
 
 # #############################################################################
@@ -45,15 +43,7 @@ class ApiEvent:
         ApiDecorators.api_client = api_client
 
         # ensure platform and others params to request
-        (
-            self.platform,
-            self.api_url,
-            self.app_url,
-            self.csw_url,
-            self.mng_url,
-            self.oc_url,
-            self.ssl,
-        ) = utils.set_base_url(self.api_client.platform)
+        self.utils = api_client.utils
         # initialize
         super(ApiEvent, self).__init__()
 
@@ -64,7 +54,7 @@ class ApiEvent:
         :param Metadata metadata: metadata (resource) to edit
         """
         # URL
-        url_events = utils.get_request_base_url(
+        url_events = self.utils.get_request_base_url(
             route="resources/{}/events".format(metadata._id)
         )
 
@@ -107,7 +97,7 @@ class ApiEvent:
             pass
 
         # URL
-        url_event = utils.get_request_base_url(
+        url_event = self.utils.get_request_base_url(
             route="resources/{}/events/{}".format(metadata_id, event_id)
         )
 
@@ -181,7 +171,7 @@ class ApiEvent:
             logger.warning("Event comments are not allowed for creation dates")
 
         # URL
-        url_event_create = utils.get_request_base_url(
+        url_event_create = self.utils.get_request_base_url(
             route="resources/{}/events".format(metadata._id)
         )
 
@@ -233,7 +223,7 @@ class ApiEvent:
             pass
 
         # URL
-        url_event_delete = utils.get_request_base_url(
+        url_event_delete = self.utils.get_request_base_url(
             route="resources/{}/events/{}".format(event.parent_resource, event._id)
         )
 
@@ -275,7 +265,7 @@ class ApiEvent:
             pass
 
         # URL
-        url_event_update = utils.get_request_base_url(
+        url_event_update = self.utils.get_request_base_url(
             route="resources/{}/events/{}".format(event.parent_resource, event._id)
         )
 
