@@ -17,7 +17,6 @@ import logging
 from isogeo_pysdk.checker import IsogeoChecker
 from isogeo_pysdk.decorators import ApiDecorators
 from isogeo_pysdk.models import FeatureAttribute, Metadata
-from isogeo_pysdk.utils import IsogeoUtils
 
 # #############################################################################
 # ########## Global #############
@@ -25,7 +24,8 @@ from isogeo_pysdk.utils import IsogeoUtils
 
 logger = logging.getLogger(__name__)
 checker = IsogeoChecker()
-utils = IsogeoUtils()
+
+available_resource_types = ["vectorDataset", "noGeoDataset"]
 
 
 # #############################################################################
@@ -43,15 +43,7 @@ class ApiFeatureAttribute:
         ApiDecorators.api_client = api_client
 
         # ensure platform and others params to request
-        (
-            self.platform,
-            self.api_url,
-            self.app_url,
-            self.csw_url,
-            self.mng_url,
-            self.oc_url,
-            self.ssl,
-        ) = utils.set_base_url(self.api_client.platform)
+        self.utils = api_client.utils
         # initialize
         super(ApiFeatureAttribute, self).__init__()
 
@@ -62,16 +54,16 @@ class ApiFeatureAttribute:
         :param Metadata metadata: metadata (resource)
         """
         # check metadata type
-        if metadata.type != "vectorDataset":
+        if metadata.type not in available_resource_types:
             raise TypeError(
-                "Feature attributes routes are only available for metadata of vector datasets, not: {}".format(
+                "Feature attributes routes are only available for metadata of vector or datasets or DTNG, not: {}".format(
                     metadata.type
                 )
             )
         else:
             pass
         # URL
-        url_feature_attributes = utils.get_request_base_url(
+        url_feature_attributes = self.utils.get_request_base_url(
             route="resources/{}/feature-attributes/".format(metadata._id)
         )
 
@@ -127,7 +119,7 @@ class ApiFeatureAttribute:
             pass
 
         # URL
-        url_feature_attribute = utils.get_request_base_url(
+        url_feature_attribute = self.utils.get_request_base_url(
             route="resources/{}/feature-attributes/{}".format(metadata_id, attribute_id)
         )
 
@@ -186,9 +178,9 @@ class ApiFeatureAttribute:
 
         """
         # check metadata type
-        if metadata.type != "vectorDataset":
+        if metadata.type not in available_resource_types:
             raise TypeError(
-                "Feature attributes routes are only available for metadata of vector datasets, not: {}".format(
+                "Feature attributes routes are only available for metadata of vector datasets or DTNG, not: {}".format(
                     metadata.type
                 )
             )
@@ -208,7 +200,7 @@ class ApiFeatureAttribute:
             attribute.dataType = ""
 
         # URL
-        url_feature_attribute_create = utils.get_request_base_url(
+        url_feature_attribute_create = self.utils.get_request_base_url(
             route="resources/{}/feature-attributes/".format(metadata._id)
         )
 
@@ -260,7 +252,7 @@ class ApiFeatureAttribute:
             pass
 
         # URL
-        url_feature_attribute_delete = utils.get_request_base_url(
+        url_feature_attribute_delete = self.utils.get_request_base_url(
             route="resources/{}/feature-attributes/{}".format(
                 attribute.parent_resource, attribute._id
             )
@@ -310,7 +302,7 @@ class ApiFeatureAttribute:
             pass
 
         # URL
-        url_feature_attribute_update = utils.get_request_base_url(
+        url_feature_attribute_update = self.utils.get_request_base_url(
             route="resources/{}/feature-attributes/{}".format(
                 attribute.parent_resource, attribute._id
             )
@@ -346,7 +338,7 @@ class ApiFeatureAttribute:
         mode: str = "add",
         case_sensitive_matching: bool = True,
     ) -> bool:
-        """Import feature-attributes from another vector metadata.
+        """Import feature-attributes from another vector (or DTNG) metadata.
 
         :param Metadata metadata_source: metadata from which to import the attributes
         :param Metadata metadata_dest: metadata where to import the attributes
@@ -358,7 +350,7 @@ class ApiFeatureAttribute:
         : param bool case_sensitive_matching: False to make featureattributes's name
         matching case-insensitive when mode == "update"
 
-        :raises TypeError: if one metadata is not a vector
+        :raises TypeError: if one metadata is not a vector or DTNG
         :raises ValueError: if mode is not one of accepted value
 
         :Example:
@@ -376,11 +368,11 @@ class ApiFeatureAttribute:
 
         # check metadata type
         if (
-            metadata_source.type != "vectorDataset"
-            or metadata_dest.type != "vectorDataset"
+            metadata_source.type not in available_resource_types
+            or metadata_dest.type not in available_resource_types
         ):
             raise TypeError(
-                "Feature attributes routes are only available for metadata of vector datasets, not: {} or {}".format(
+                "Feature attributes routes are only available for metadata of vector datasets or DTNG, not: {} or {}".format(
                     metadata_source.type, metadata_dest.type
                 )
             )
