@@ -26,7 +26,6 @@ from isogeo_pysdk.checker import IsogeoChecker
 from isogeo_pysdk.decorators import ApiDecorators
 from isogeo_pysdk.enums import LinkActions, LinkKinds, LinkTypes
 from isogeo_pysdk.models import Link, Metadata
-from isogeo_pysdk.utils import IsogeoUtils
 
 # #############################################################################
 # ########## Global #############
@@ -34,7 +33,6 @@ from isogeo_pysdk.utils import IsogeoUtils
 
 logger = logging.getLogger(__name__)
 checker = IsogeoChecker()
-utils = IsogeoUtils()
 
 
 # #############################################################################
@@ -52,15 +50,7 @@ class ApiLink:
         ApiDecorators.api_client = api_client
 
         # ensure platform and others params to request
-        (
-            self.platform,
-            self.api_url,
-            self.app_url,
-            self.csw_url,
-            self.mng_url,
-            self.oc_url,
-            self.ssl,
-        ) = utils.set_base_url(self.api_client.platform)
+        self.utils = api_client.utils
         # initialize
         super(ApiLink, self).__init__()
 
@@ -71,7 +61,7 @@ class ApiLink:
         :param Metadata metadata: metadata (resource)
         """
         # request URL
-        url_links = utils.get_request_base_url(
+        url_links = self.utils.get_request_base_url(
             route="resources/{}/links/".format(metadata._id)
         )
 
@@ -92,7 +82,6 @@ class ApiLink:
         # end of method
         return req_links.json()
 
-    @lru_cache()
     @ApiDecorators._check_bearer_validity
     def get(self, metadata_id: str, link_id: str) -> Link:
         """Get details about a specific link.
@@ -131,7 +120,7 @@ class ApiLink:
             pass
 
         # URL
-        url_link = utils.get_request_base_url(
+        url_link = self.utils.get_request_base_url(
             route="resources/{}/links/{}".format(metadata_id, link_id)
         )
 
@@ -157,11 +146,14 @@ class ApiLink:
         return Link(**link_augmented)
 
     @ApiDecorators._check_bearer_validity
-    def create(self, metadata: Metadata, link: Link) -> Link:
+    def create(
+        self, metadata: Metadata, link: Link, clean_actions: bool = True
+    ) -> Link:
         """Add a new link to a metadata (= resource).
 
         :param Metadata metadata: metadata (resource) to edit
         :param Link link: link object to create
+        :param bool clean_actions: if True, clean link actions depending on link kind
 
         :returns: the created link or a tuple with the request's response error code
 
@@ -232,9 +224,12 @@ class ApiLink:
             pass
 
         # check relation between link kind/actions
-        link.actions = self.clean_kind_action_liability(
-            link_actions=tuple(link.actions), link_kind=link.kind
-        )
+        if clean_actions:
+            link.actions = self.clean_kind_action_liability(
+                link_actions=tuple(link.actions), link_kind=link.kind
+            )
+        else:
+            pass
 
         # deprecation warnings
         if link.kind in (
@@ -260,7 +255,7 @@ class ApiLink:
             )
 
         # URL
-        url_link_create = utils.get_request_base_url(
+        url_link_create = self.utils.get_request_base_url(
             route="resources/{}/links".format(metadata._id)
         )
 
@@ -310,7 +305,7 @@ class ApiLink:
             pass
 
         # URL
-        url_link_delete = utils.get_request_base_url(
+        url_link_delete = self.utils.get_request_base_url(
             route="resources/{}/links/{}".format(link.parent_resource, link._id)
         )
 
@@ -352,7 +347,7 @@ class ApiLink:
             pass
 
         # URL
-        url_link_update = utils.get_request_base_url(
+        url_link_update = self.utils.get_request_base_url(
             route="resources/{}/links/{}".format(link.parent_resource, link._id)
         )
 
@@ -416,7 +411,7 @@ class ApiLink:
             pass
 
         # request URL
-        url_download_hosted = utils.get_request_base_url(route=link.url)
+        url_download_hosted = self.utils.get_request_base_url(route=link.url)
 
         # request
         req_download_hosted = self.api_client.get(
@@ -442,11 +437,11 @@ class ApiLink:
 
         # remove special characters
         if encode_clean:
-            filename = utils.encoded_words_to_text(filename)
+            filename = self.utils.encoded_words_to_text(filename)
             filename = re.sub(r"[^\w\-_\. ]", "", filename)
 
         # end of method
-        return (req_download_hosted, filename, utils.convert_octets(link.size))
+        return (req_download_hosted, filename, self.utils.convert_octets(link.size))
 
     @ApiDecorators._check_bearer_validity
     def upload_hosted(
@@ -532,7 +527,7 @@ class ApiLink:
             )
 
         # URL
-        url_link_create = utils.get_request_base_url(
+        url_link_create = self.utils.get_request_base_url(
             route="resources/{}/links".format(metadata._id)
         )
 
@@ -640,7 +635,7 @@ class ApiLink:
 
         """
         # request URL
-        url_links = utils.get_request_base_url(route="link-kinds/")
+        url_links = self.utils.get_request_base_url(route="link-kinds/")
 
         # request
         req_links = self.api_client.get(
