@@ -22,7 +22,6 @@ from requests.models import Response
 from isogeo_pysdk.checker import IsogeoChecker
 from isogeo_pysdk.decorators import ApiDecorators
 from isogeo_pysdk.models import Conformity, Metadata, Specification
-from isogeo_pysdk.utils import IsogeoUtils
 
 # #############################################################################
 # ########## Global #############
@@ -30,7 +29,6 @@ from isogeo_pysdk.utils import IsogeoUtils
 
 logger = logging.getLogger(__name__)
 checker = IsogeoChecker()
-utils = IsogeoUtils()
 
 
 # #############################################################################
@@ -48,19 +46,10 @@ class ApiSpecification:
         ApiDecorators.api_client = api_client
 
         # ensure platform and others params to request
-        (
-            self.platform,
-            self.api_url,
-            self.app_url,
-            self.csw_url,
-            self.mng_url,
-            self.oc_url,
-            self.ssl,
-        ) = utils.set_base_url(self.api_client.platform)
+        self.utils = api_client.utils
         # initialize
         super(ApiSpecification, self).__init__()
 
-    @lru_cache()
     @ApiDecorators._check_bearer_validity
     def listing(
         self,
@@ -87,7 +76,7 @@ class ApiSpecification:
             payload = None
 
         # request URL
-        url_specifications = utils.get_request_base_url(
+        url_specifications = self.utils.get_request_base_url(
             route="groups/{}/specifications".format(workgroup_id)
         )
 
@@ -130,7 +119,7 @@ class ApiSpecification:
             pass
 
         # specification route
-        url_specification = utils.get_request_base_url(
+        url_specification = self.utils.get_request_base_url(
             route="specifications/{}".format(specification_id)
         )
 
@@ -193,7 +182,7 @@ class ApiSpecification:
             pass
 
         # build request url
-        url_specification_create = utils.get_request_base_url(
+        url_specification_create = self.utils.get_request_base_url(
             route="groups/{}/specifications".format(workgroup_id)
         )
 
@@ -246,7 +235,7 @@ class ApiSpecification:
             pass
 
         # request URL
-        url_specification_delete = utils.get_request_base_url(
+        url_specification_delete = self.utils.get_request_base_url(
             route="groups/{}/specifications/{}".format(workgroup_id, specification_id)
         )
 
@@ -286,7 +275,7 @@ class ApiSpecification:
 
         # URL builder
         url_specification_exists = "{}{}".format(
-            utils.get_request_base_url("specifications"), specification_id
+            self.utils.get_request_base_url("specifications"), specification_id
         )
 
         # request
@@ -321,7 +310,7 @@ class ApiSpecification:
             pass
 
         # URL
-        url_specification_update = utils.get_request_base_url(
+        url_specification_update = self.utils.get_request_base_url(
             route="groups/{}/specifications/{}".format(
                 specification.owner.get("_id"), specification._id
             )
